import { __assign } from "tslib";
import { ArrowLeftIcon, ArrowRightIcon } from '@heroicons/react/20/solid';
import React, { useEffect, useState } from 'react';
import { checkActive, checkDisabled, createMonthCalendarWithAdjacentMonths, formatDate, getMonthName } from '../utils';
function classNames() {
    var classes = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        classes[_i] = arguments[_i];
    }
    return classes.filter(Boolean).join(' ');
}
export default function Calendar(_a) {
    var defaultDate = _a.defaultDate, disabledDate = _a.disabledDate, endDisabled = _a.endDisabled, inputValue = _a.inputValue, max = _a.max, min = _a.min, onChangeDate = _a.onChangeDate, startDisabled = _a.startDisabled;
    var currentDate = formatDate(new Date());
    var _b = useState(new Date().getFullYear()), currentYear = _b[0], setCurrentYear = _b[1];
    var _c = useState(new Date().getMonth()), currentMonth = _c[0], setCurrentMonth = _c[1];
    var _d = useState([]), calendar = _d[0], setCalendar = _d[1];
    var _e = useState(''), daySelected = _e[0], setDaySelected = _e[1];
    var checkToday = function (dayOfWeek) {
        var _a;
        var today = (_a = calendar.find(function (item) { return item.date === currentDate; })) === null || _a === void 0 ? void 0 : _a.dayOfWeek;
        return today === dayOfWeek;
    };
    useEffect(function () {
        var calendar = createMonthCalendarWithAdjacentMonths(currentYear, currentMonth);
        var selectedCalendar = calendar.map(function (item) { return (__assign(__assign({}, item), { isSelected: checkActive(daySelected, item.date), disabled: checkDisabled({
                startDisabled: startDisabled,
                endDisabled: endDisabled,
                date: item.date,
                disabledDate: disabledDate,
                max: max,
                min: min
            }) })); });
        setCalendar(selectedCalendar);
    }, [daySelected, currentMonth, currentYear, max, min]);
    useEffect(function () {
        var selectDate = function (inputValue, daySplit) {
            if (daySplit.length >= 3) {
                setDaySelected(inputValue);
                setCurrentMonth(parseInt(daySplit[1]) - 1);
                setCurrentYear(parseInt(daySplit[2]));
            }
        };
        if (inputValue) {
            // @ts-ignore
            var daySplit = inputValue === null || inputValue === void 0 ? void 0 : inputValue.split('-');
            selectDate(inputValue, daySplit);
        }
    }, [inputValue]);
    useEffect(function () {
        if (defaultDate) {
            // @ts-ignore
            setDaySelected(defaultDate);
            var daySplit = defaultDate === null || defaultDate === void 0 ? void 0 : defaultDate.split('-');
            setCurrentMonth(parseInt(daySplit[1]) - 1);
            setCurrentYear(parseInt(daySplit[2]));
        }
        else {
            return;
        }
    }, [max, min]);
    var handleClick = function (day) {
        if (!day.disabled) {
            var dateSelected = day.date.split('-');
            setCurrentMonth(parseInt(dateSelected[1]) - 1);
            setCurrentYear(parseInt(dateSelected[2]));
            setDaySelected(day.date);
            if (onChangeDate) {
                // @ts-ignore
                onChangeDate({
                    date: new Date(parseInt(dateSelected[2]), parseInt(dateSelected[1]) - 1, parseInt(dateSelected[0])),
                    format: day.date
                });
            }
        }
        else
            return;
    };
    var handleChangeMonth = function (type) {
        if (type === 'next') {
            if (currentMonth === 11) {
                setCurrentMonth(0);
                setCurrentYear(currentYear + 1);
            }
            else
                setCurrentMonth(currentMonth + 1);
        }
        else {
            if (currentMonth === 0) {
                setCurrentMonth(11);
                setCurrentYear(currentYear - 1);
            }
            else
                setCurrentMonth(currentMonth - 1);
        }
    };
    return (React.createElement("div", null,
        React.createElement("div", { className: 'w-[21rem] rounded-lg border-[0.5px] border-gray-200 bg-white px-3 py-2 shadow-lg sm:w-[26rem]' },
            React.createElement("div", { className: 'text-center lg:col-start-8 lg:col-end-13 lg:row-start-1 xl:col-start-9' },
                React.createElement("div", { className: 'flex items-center text-gray-900' },
                    React.createElement("button", { className: '-m-1.5 flex flex-none items-center justify-center rounded-lg p-1 text-gray-400 hover:bg-gray-200', onClick: function () { return handleChangeMonth('prev'); }, type: 'button' },
                        React.createElement("span", { className: 'sr-only' }, "Previous month"),
                        React.createElement(ArrowLeftIcon, { "aria-hidden": 'true', className: 'h-5 w-5' })),
                    React.createElement("div", { className: 'flex-auto text-xs font-medium' }, getMonthName(currentMonth) + ' ' + currentYear),
                    React.createElement("button", { className: '-m-1.5 flex flex-none items-center justify-center rounded-lg p-1 text-gray-400 hover:bg-gray-200', onClick: function () { return handleChangeMonth('next'); }, type: 'button' },
                        React.createElement("span", { className: 'sr-only' }, "Next month"),
                        React.createElement(ArrowRightIcon, { "aria-hidden": 'true', className: 'h-5 w-5' }))),
                React.createElement("div", { className: 'mt-4 grid grid-cols-7 text-[0.75rem] text-xs font-normal text-gray-500' },
                    React.createElement("div", { className: classNames(checkToday(1) && '!font-semibold !text-gray-900') }, "T2"),
                    React.createElement("div", { className: classNames(checkToday(2) && '!font-semibold !text-gray-900') }, "T3"),
                    React.createElement("div", { className: classNames(checkToday(3) && '!font-semibold !text-gray-900') }, "T4"),
                    React.createElement("div", { className: classNames(checkToday(4) && '!font-semibold !text-gray-900') }, "T5"),
                    React.createElement("div", { className: classNames(checkToday(5) && '!font-semibold !text-gray-900') }, "T6"),
                    React.createElement("div", { className: classNames(checkToday(6) && '!font-semibold !text-gray-900') }, "T7"),
                    React.createElement("div", { className: classNames(checkToday(0) && '!font-semibold !text-gray-900') }, "CN")),
                React.createElement("div", { className: 'isolate mt-2 grid grid-cols-7 rounded-lg text-xs' }, calendar.map(function (day) { return (React.createElement("button", { key: day.date, className: classNames('cursor-pointer rounded-lg py-[0.425rem] text-[0.75rem]  font-light text-gray-800 hover:!bg-indigo-900 hover:text-white focus:z-10', day.isCurrentMonth ? 'bg-white' : 'text-gray-300', day.isToday ? 'font-semibold text-gray-900' : 'font-normal', day.disabled && day.isCurrentMonth
                        ? '!cursor-default !text-gray-300 hover:!bg-transparent hover:!text-gray-300'
                        : '', !day.isToday && day.isCurrentMonth && !day.isSelected && !day.disabled && 'text-gray-700', day.isSelected && '!bg-indigo-800 text-white', !day.isCurrentMonth && 'hidden'), onClick: function () { return handleClick(day); }, style: { gridColumn: day.dayOfWeek === 0 ? 7 : day.dayOfWeek }, type: 'button' },
                    React.createElement("time", { className: '', dateTime: day.date }, day.date.split('-')[0].replace(/^0/, '')))); }))))));
}
//# sourceMappingURL=Calendar.js.map